@@ -48,6 +48,12 @@ class DynamicField(models.Model):
         global dfields
         dfields =  DynamicField.objects.all()
 
+    def delete(self, *args, **kwargs):
+        super(DynamicField, self).delete(*args, **kwargs)
+        # NOTE: force update global dfields fieldset
+        global dfields
+        dfields =  DynamicField.objects.all()
+
 
 # XXX: Charge memory with all dfields for prevent flood on db.
 dfields =  DynamicField.objects.all()
@@ -178,7 +184,12 @@ class HStoreModelMeta(models.Model.__metaclass__):
                 raise FieldDoesNotExist('%s has no field named %r' % (self.object_name, name))
 
             def get_all_field_names(self):
-                return get_fieldnames(self.fields, ['_dfields'])
+                declared_and_dfields = set(get_fieldnames(self.fields, ['_dfields']))
+                relation_fields = set()
+                if hasattr(self, '_name_map'):
+                    relation_fields = set(getattr(self, '_name_map').keys())
+                all_fields = list(declared_and_dfields.union(relation_fields))
+                return all_fields
 
             def get_all_dynamic_field_names(self):
                 return get_fieldnames(self.dynamic_fields)
